@@ -9,7 +9,6 @@ import datetime
 
 import pandas as pd
 import numpy as np
-import polars as pl
 
 import math
 import json
@@ -22,7 +21,7 @@ import plotly.express as px
 import plotly.graph_objs as go
 from plotly.subplots import make_subplots
 
-import plotguy
+#import plotguy
 #import dash_dangerously_set_inner_html   # for all Plot Class
 
 
@@ -105,7 +104,6 @@ class Components:
 
         return fig_line
 
-
     def update_checkbox_div(self, para_keys, backtest_result_df):
         checkbox_values = {}
 
@@ -221,7 +219,6 @@ class Components:
 
         return div
 
-
     def generate_radioitems(self, para_dict):
         radioitems_div = []
 
@@ -252,7 +249,6 @@ class Components:
 
         return title
 
-
     def update_performance_matrix(self, init_chart, para_keys_list, result_df, line_selected = 0):
 
         if init_chart:
@@ -490,7 +486,6 @@ class Components:
 
         return matrix_div
 
-
     filter_options = {
         'num_of_trade':'Number of Trade',
         'equity_return_on_capital': 'Return on Capital',
@@ -527,7 +522,6 @@ class Components:
 
         return filter_btn
 
-
     def generate_sorted_df(self, sort_method, df_checked, number_of_curves):
 
         if sort_method == 'Top Sharpe Ratio':
@@ -551,7 +545,6 @@ class Components:
 
         return df_checked
 
-
     def assign_colour(self, profile, degree):
         if profile == 0:    rgb = (0, int(252 - 252 * degree), 252)
         elif profile == 1:  rgb = (int(252 - 252 * degree), 252, 0)
@@ -561,94 +554,6 @@ class Components:
         elif profile == 5:  rgb = (int(252 * degree), 0, 252)
         return 'rgb' + str(rgb)
 
-    def generate_chart_3(self, para_combination, chart3_start, chart3_end, freq):
-
-        data_folder = para_combination['data_folder']
-        code = para_combination['code']
-        start_date = para_combination['start_date']
-        end_date = para_combination['end_date']
-        data_path = os.path.join(data_folder, f'{code}_{freq}.parquet')
-
-        df = pd.read_parquet(data_path)  # Daraframe that may not be daily
-
-        df = df.reset_index(drop=False)
-
-        df['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
-        df['datetime'] = pd.to_datetime(df['datetime'], format='%Y-%m-%d %H:%M:%S')
-        df = df.loc[(df['date'] >= chart3_start) & (df['date'] <= chart3_end)]
-
-        # grab first and last observations from df.date and make a continuous date range from that
-        dt_all = pd.date_range(start=df['datetime'].iloc[0], end=df['datetime'].iloc[-1], freq=freq)
-        # check which dates from your source that also accur in the continuous date range
-        dt_obs = [d.strftime("%Y-%m-%d %H:%M:%S") for d in df['datetime']]
-        # isolate missing timestamps
-        dt_breaks = [d for d in dt_all.strftime("%Y-%m-%d %H:%M:%S").tolist() if not d in dt_obs]
-
-        ###### chagne ######
-        save_path = plotguy.generate_save_path(para_combination=para_combination)
-        df_signal_list = plotguy.read_daily_df(save_path, start_date, end_date, freq)
-        ####################
-
-        df_signal_list = df_signal_list.loc[
-            (df_signal_list['date'] >= chart3_start) & (df_signal_list['date'] <= chart3_end)]
-
-        df_open = df_signal_list.loc[df_signal_list['action'] == 'open']
-        df_profit = df_signal_list.loc[df_signal_list['action'] == 'profit_target']
-        df_stop_loss = df_signal_list.loc[df_signal_list['action'] == 'stop_loss']
-        df_close = df_signal_list.loc[df_signal_list['action'] == 'close_logic']
-        df_close = df_signal_list.loc[df_signal_list['action'] == 'close_logic']
-
-        fig = go.Figure(data=[go.Candlestick(x=df['datetime'],
-                                             open=df['open'],
-                                             high=df['high'],
-                                             low=df['low'],
-                                             close=df['close'],
-                                             increasing_line_color='white')
-                              ])
-
-        fig.update_layout(title = {'text': 'Candlestick Chart' , 'font': {'size': 12 }  })
-
-        fig.update_xaxes(rangebreaks=[dict(dvalue=15 * 60 * 1000, values=dt_breaks)])
-
-        fig.add_trace(go.Scatter(mode='markers',
-                                 #x=df_open['datetime'], y=df_open['close'],  # visible='legendonly',
-                                 x=df_open.index, y=df_open['close'],  # visible='legendonly',
-                                 marker=dict(color='rgba(0, 0, 0, 0)', size=18,
-                                             line=dict(color='yellow', width=2.5)), name='Open'))
-        fig.add_trace(go.Scatter(mode='markers',
-                                 #x=df_profit['datetime'], y=df_profit['close'],  # visible='legendonly',
-                                 x=df_profit.index, y=df_profit['close'],  # visible='legendonly',
-                                 marker=dict(color='rgba(0, 0, 0, 0)', size=18,
-                                             line=dict(color='Cyan', width=2.5)), name='Profit Target'))
-        fig.add_trace(go.Scatter(mode='markers',
-                                 #x=df_stop_loss['datetime'], y=df_stop_loss['close'],  # visible='legendonly',
-                                 x=df_stop_loss.index, y=df_stop_loss['close'],  # visible='legendonly',
-                                 marker=dict(color='rgba(0, 0, 0, 0)', size=18,
-                                             line=dict(color='Cyan', width=2.5)), name='Stop Loss'))
-        fig.add_trace(go.Scatter(mode='markers',
-                                 #x=df_close['datetime'], y=df_close['close'],  # visible='legendonly',
-                                 x=df_close.index, y=df_close['close'],  # visible='legendonly',
-                                 marker=dict(color='rgba(0, 0, 0, 0)', size=18,
-                                             line=dict(color='Cyan', width=2.5)), name='Close Logic'))
-
-        fig.update_layout(xaxis_rangeslider_visible=True)
-
-        chart_bg = '#1f2c56'
-        fig.update_layout(plot_bgcolor=chart_bg, paper_bgcolor=chart_bg, height=500,
-                          margin=dict(l=85, r=25, t=60, b=0),
-                          showlegend=True,
-                          font={"color": "white", 'size': 10.5}, yaxis={'title': 'Equity'},
-                          xaxis={'title': ''}
-                          )
-        fig.update_xaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor=chart_bg)
-        fig.update_yaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor=chart_bg)
-
-
-
-
-        return fig
-
-
     def generate_main_chart(self, graph_df, backtest_name, equity_curve_folder, para_keys_list):
 
 
@@ -719,8 +624,6 @@ class Components:
 
         return fig_line
 
-
-
     def generate_stra_alys_chart(self, intraday, graph_df, line_selected,
                                  para_keys_list, backtest_result_dict):
 
@@ -850,7 +753,6 @@ class Components:
 
         return fig_line
 
-
     ### for class signal ###
     def generate_df_stat(self, df, period):
         col_pct = 'pct_change_' + str(period)
@@ -874,7 +776,6 @@ class Components:
 
         return round(df_his[col_pct].mean(), 2), round(df_his[col_rise].mean(), 2), round(df_his[col_fall].mean(), 2)
 
-
     def aggregate_df(self):
         all_str_dir = []
         for folder_name in os.listdir():
@@ -1119,7 +1020,6 @@ class Components:
 
         return df_show_agg, row
 
-
     def aggregate_performance(self, total_dict, year_list, risk_free_rate):
         num_of_trade = "{:,}".format(int(total_dict['num_of_trade']))
         net_profit = "{:,}".format(int(round(total_dict['net_profit'],0)) )
